import type * as Types from "./types";
import * as Classes from "./classes";
import * as helpers from "./helpers";
/**
 * Manages keyboard event bindings and execution of callback functions for specific key combinations.
 */
declare class BindKeyboard {
    #private;
    /**
     * Creates an instance of the Keybind class.
     *
     * @param {Types.ConstructorProps} [props={}] - Configuration options for the Keybind instance.
     * @param {EventTarget} [props.target=globalThis] - The target element for listening to keyboard events (optional, default is window).
     * @param {Types.DebugLevel} [props.debug=0] - The level of debugging output (0 - None, 1 - Only exsisting bindings, 2 - All key events) (optional, default is 0).
     * @param {boolean} [props.checkInputElements=false] - Whether to prevent intercepting key events when typing in input fields (optional, default is false).
     * @param {boolean} [props.autostart=true] - Whether to prevent intercepting key events when typing in input fields (optional, default is false).
     * @param {Types.KeybindInitializer[]} [props.initialBindings=undefined] - Initial key bindings to set upon instantiation (optional, default is undefined).
     */
    constructor(props?: Types.ConstructorProps);
    /**
     * @extends keyParser
     */
    static keyParser: (keyCombination: string | Partial<Pick<KeyboardEvent, "shiftKey" | "ctrlKey" | "altKey" | "metaKey" | "key">>) => string;
    /**
     * @extends helpers.getKeyСombination
     */
    static getKeyСombination: ({ ctrlKey, shiftKey, altKey, metaKey, key, }: Partial<Pick<KeyboardEvent, "shiftKey" | "ctrlKey" | "altKey" | "metaKey" | "key">>) => string;
    /**
     * Gets the binding for a specific key combination and event type.
     *
     * @param {Types.KeyСombination | Types.KeyСombinationConstruct} keyCombination - The key combination to look up.
     * @param {Types.EventType} [type='keypress'] - The type of keyboard event to search (optional, default is 'keypress').
     * @returns {Classes.KeybindEntry | undefined} The key binding entry or undefined if not found.
     */
    getKeybind: (keyCombination: Types.KeyСombination | Types.KeyСombinationConstruct, type?: Types.EventType) => Classes.KeybindEntry | undefined;
    /**
     * Gets an array of all key bindings across all event types.
     *
     * @returns {Classes.KeybindEntry[]} An array of all key bindings.
     */
    getAllBindings: () => Classes.KeybindEntry[];
    /**
     * Adds a keyboard event binding for a specific key combination.
     *
     * @param {Types.KeyСombination | Types.KeyСombinationConstruct} keyCombination - The key combination to bind.
     * @param {EventListener} callback - The callback function to execute when the key combination is pressed.
     * @param {boolean} [preventRepeat=true] - Whether to prevent repeated key press events when holding down the key (optional, default is true).
     * @param {Types.EventType} [type='keypress'] - The type of keyboard event to bind (optional, default is 'keypress').
     * @throws {Classes.KeybindError} When an invalid EventType is provided.
     */
    add: (keyCombination: Types.KeyСombination | Types.KeyСombinationConstruct, callback: EventListener, preventRepeat?: boolean, type?: Types.EventType) => Map<string, Classes.KeybindEntry> | undefined;
    /**
     * Removes a keyboard event binding for a specific key combination.
     *
     * @param {Types.KeyСombination | Types.KeyСombinationConstruct} keyCombination - The key combination to unbind.
     * @param {Types.EventType} [type='keypress'] - The type of keyboard event to unbind (optional, default is 'keypress').
     * @throws {Classes.KeybindError} When an invalid EventType is provided.
     */
    remove: (keyCombination: Types.KeyСombination | Types.KeyСombinationConstruct, type?: Types.EventType) => boolean | undefined;
    /**
     * Removes all keyboard event bindings.
     */
    removeAll: () => void;
    /**
     * Starts listening for keyboard events on the target element.
     */
    startListners: () => void;
    /**
     * Stops listening for keyboard events on the target element.
     */
    stopListners: () => void;
    /**
     * @returns {EventTarget}.
     */
    getTarget: () => EventTarget;
}
export default BindKeyboard;
export { BindKeyboard, Classes, helpers };
